# History

## 0.6.0 (2022-03-28)

* Add `GraphQLSchemaBuilder` to build the `graphql`'s schema.
* Add `GraphQlHandler` class to handle `graphql` requests.
* Add `GraphQlHttpRouter` class to route `http` request to `graphql`.
* Add `GraphQlEnroute`, `GraphQlEnrouteDecorator`, `GraphQlCommandEnrouteDecorator` and `GraphQlQueryEnrouteDecorator` decorators.

## 0.7.0 (2022-05-11)

* Minor improvements.
* Unify documentation building pipeline across all `minos-python` packages.
* Fix documentation building warnings.
* Fix bug related with package building and additional files like `AUTHORS.md`, `HISTORY.md`, etc.